@@ -64,18 +64,34 @@ impl ActionBuilderWrapper {
 }
 
 /**
-Trait that must be defined by types in order to be `ActionBuilder`s. `ActionBuilder`s' job is to spawn new `Action` entities. In general, most of this is already done for you, and the only method you really have to implement is `.build()`.
+Trait that must be defined by types in order to be `ActionBuilder`s. `ActionBuilder`s' job is to spawn new `Action` entities on demand. In general, most of this is already done for you, and the only method you really have to implement is `.build()`.
 
 The `build()` method MUST be implemented for any `ActionBuilder`s you want to define.
 */
 pub trait ActionBuilder: std::fmt::Debug + Send + Sync {
     /**
-    MUST insert your concrete Action component into the `action` [`Entity`], using `cmd`. You _may_ use `actor`, but it's perfectly normal to just ignore it.
+
+    MUST insert your concrete Action component into the Scorer [`Entity`], using
+     `cmd`. You _may_ use `actor`, but it's perfectly normal to just ignore it.
+
+    Note that this method is automatically implemented for any Components that
+    implement Clone, so you don't need to define it yourself unless you want
+    more complex parameterization of your Actions.
 
     ### Example
 
+    Using `Clone` (the easy way):
+
+    ```no_run
+    #[derive(Debug, Clone, Component)]
+    struct MyAction;
+    ```
+
+    Implementing it manually:
+
     ```no_run
     struct MyBuilder;
+    #[derive(Debug, Component)]
     struct MyAction;
 
     impl ActionBuilder for MyBuilder {
@@ -87,10 +103,9 @@ pub trait ActionBuilder: std::fmt::Debug + Send + Sync {
     */
     fn build(&self, cmd: &mut Commands, action: Entity, actor: Entity);
 
-    /**
-    Don't implement this yourself unless you know what you're doing.
-     */
-    fn attach(&self, cmd: &mut Commands, actor: Entity) -> Entity {
+    #[doc(hidden)]
+    // Don't implement this yourself unless you know what you're doing.
+    fn spawn_action(&self, cmd: &mut Commands, actor: Entity) -> Entity {
         let action_ent = ActionEnt(cmd.spawn().id());
         cmd.entity(action_ent.0)
             .insert(Name::new("Action"))
@@ -101,6 +116,15 @@ pub trait ActionBuilder: std::fmt::Debug + Send + Sync {
     }
 }
 
+impl<T> ActionBuilder for T
+where
+    T: Component + Clone + std::fmt::Debug + Send + Sync,
+{
+    fn build(&self, cmd: &mut Commands, action: Entity, _actor: Entity) {
+        cmd.entity(action).insert(T::clone(self));
+    }
+}
+
 /**
 [`ActionBuilder`] for the [`Steps`] component. Constructed through `Steps::build()`.
 */
@@ -122,7 +146,7 @@ impl StepsBuilder {
 impl ActionBuilder for StepsBuilder {
     fn build(&self, cmd: &mut Commands, action: Entity, actor: Entity) {
         if let Some(step) = self.steps.get(0) {
-            let child_action = step.attach(cmd, actor);
+            let child_action = step.spawn_action(cmd, actor);
             cmd.entity(action)
                 .insert(Name::new("Steps Action"))
                 .insert(Steps {
@@ -130,6 +154,8 @@ impl ActionBuilder for StepsBuilder {
                     active_ent: ActionEnt(child_action),
                     steps: self.steps.clone(),
                 })
+                .insert(Transform::default())
+                .insert(GlobalTransform::default())
                 .push_children(&[child_action]);
         }
     }
@@ -145,8 +171,8 @@ Thinker::build()
     .when(
         MyScorer,
         Steps::build()
-            .step(MyAction::build())
-            .step(MyNextAction::build())
+            .step(MyAction)
+            .step(MyNextAction)
         )
 ```
 */
@@ -214,7 +240,7 @@ pub fn steps_system(
 
                         steps_action.active_step += 1;
                         let step_builder = steps_action.steps[steps_action.active_step].clone();
-                        let step_ent = step_builder.attach(&mut cmd, *actor);
+                        let step_ent = step_builder.spawn_action(&mut cmd, *actor);
                         cmd.entity(seq_ent).push_children(&[step_ent]);
                         steps_action.active_ent.0 = step_ent;
                     }
@@ -237,7 +263,7 @@ pub fn steps_system(
 }
 
 /**
-[`ActionBuilder`] for the [`Concurrent`] component. Constructed through `Concurrent::build()`.
+[`ActionBuilder`] for the [`Concurrently`] component. Constructed through `Concurrently::build()`.
 */
 #[derive(Debug)]
 pub struct ConcurrentlyBuilder {
@@ -259,10 +285,12 @@ impl ActionBuilder for ConcurrentlyBuilder {
         let children: Vec<Entity> = self
             .actions
             .iter()
-            .map(|action| action.attach(cmd, actor))
+            .map(|action| action.spawn_action(cmd, actor))
             .collect();
         cmd.entity(action)
             .insert(Name::new("Concurrent Action"))
+            .insert(Transform::default())
+            .insert(GlobalTransform::default())
             .push_children(&children[..])
             .insert(Concurrently {
                 actions: children.into_iter().map(ActionEnt).collect(),
@@ -280,8 +308,8 @@ Thinker::build()
     .when(
         MyScorer,
         Concurrent::build()
-            .push(MyAction::build())
-            .push(MyOtherAction::build())
+            .push(MyAction)
+            .push(MyOtherAction)
         )
 ```
 */
@@ -292,7 +320,7 @@ pub struct Concurrently {
 
 impl Concurrently {
     /**
-    Construct a new [`ConcurrentBuilder`] to define the actions to take.
+    Construct a new [`ConcurrentlyBuilder`] to define the actions to take.
     */
     pub fn build() -> ConcurrentlyBuilder {
         ConcurrentlyBuilder {
@@ -302,7 +330,7 @@ impl Concurrently {
 }
 
 /**
-System that takes care of executing any existing [`Concurrent`] Actions.
+System that takes care of executing any existing [`Concurrently`] Actions.
 */
 pub fn concurrent_system(
     concurrent_q: Query<(Entity, &Concurrently)>,
