@@ -37,7 +37,7 @@ impl ChoiceBuilder {
     }
 
     pub fn build(&self, cmd: &mut Commands, actor: Entity, parent: Entity) -> Choice {
-        let scorer_ent = self.when.attach(cmd, actor);
+        let scorer_ent = self.when.spawn_scorer(cmd, actor);
         cmd.entity(parent).push_children(&[scorer_ent]);
         Choice {
             scorer: ScorerEnt(scorer_ent),
