@@ -46,12 +46,27 @@ The `build()` method MUST be implemented for any `ScorerBuilder`s you want to de
 */
 pub trait ScorerBuilder: std::fmt::Debug + Sync + Send {
     /**
-    MUST insert your concrete Scorer component into the Scorer [`Entity`], using `cmd`. You _may_ use `actor`, but it's perfectly normal to just ignore it.
+    MUST insert your concrete Scorer component into the Scorer [`Entity`], using
+     `cmd`. You _may_ use `actor`, but it's perfectly normal to just ignore it.
+
+    Note that this method is automatically implemented for any Components that
+    implement Clone, so you don't need to define it yourself unless you want
+    more complex parameterization of your Actions.
 
     ### Example
 
+    Using `Clone` (the easy way):
+
+    ```no_run
+    #[derive(Debug, Clone, Component)]
+    struct MyScorer;
+    ```
+
+    Implementing it manually:
+
     ```no_run
     struct MyBuilder;
+    #[derive(Debug, Component)]
     struct MyScorer;
 
     impl ScorerBuilder for MyBuilder {
@@ -63,10 +78,9 @@ pub trait ScorerBuilder: std::fmt::Debug + Sync + Send {
     */
     fn build(&self, cmd: &mut Commands, scorer: Entity, actor: Entity);
 
-    /**
-    Don't implement this yourself unless you know what you're doing.
-     */
-    fn attach(&self, cmd: &mut Commands, actor: Entity) -> Entity {
+    // Don't implement this yourself unless you know what you're doing.
+    #[doc(hidden)]
+    fn spawn_scorer(&self, cmd: &mut Commands, actor: Entity) -> Entity {
         let scorer_ent = cmd.spawn().id();
         cmd.entity(scorer_ent)
             .insert(Name::new("Scorer"))
@@ -77,33 +91,27 @@ pub trait ScorerBuilder: std::fmt::Debug + Sync + Send {
     }
 }
 
+impl<T> ScorerBuilder for T
+where
+    T: Component + Clone + std::fmt::Debug + Send + Sync,
+{
+    fn build(&self, cmd: &mut Commands, action: Entity, _actor: Entity) {
+        cmd.entity(action).insert(T::clone(self));
+    }
+}
+
 /**
 Scorer that always returns the same, fixed score. Good for combining with things creatively!
  */
 #[derive(Clone, Component, Debug)]
 pub struct FixedScore(f32);
 
-impl FixedScore {
-    pub fn build(score: f32) -> FixedScoreBuilder {
-        FixedScoreBuilder(score)
-    }
-}
-
 pub fn fixed_score_system(mut query: Query<(&FixedScore, &mut Score)>) {
     for (FixedScore(fixed), mut score) in query.iter_mut() {
         score.set(*fixed);
     }
 }
 
-#[derive(Clone, Component, Debug)]
-pub struct FixedScoreBuilder(f32);
-
-impl ScorerBuilder for FixedScoreBuilder {
-    fn build(&self, cmd: &mut Commands, action: Entity, _actor: Entity) {
-        cmd.entity(action).insert(FixedScore(self.0));
-    }
-}
-
 /**
 Composite Scorer that takes any number of other Scorers and returns the sum of their [`Score`] values if each _individual_ [`Score`] is at or above the configured `threshold`.
 
@@ -177,10 +185,12 @@ impl ScorerBuilder for AllOrNothingBuilder {
         let scorers: Vec<_> = self
             .scorers
             .iter()
-            .map(|scorer| scorer.attach(cmd, actor))
+            .map(|scorer| scorer.spawn_scorer(cmd, actor))
             .collect();
         cmd.entity(scorer)
             .insert(Score::default())
+            .insert(Transform::default())
+            .insert(GlobalTransform::default())
             .push_children(&scorers[..])
             .insert(Name::new("Scorer"))
             .insert(AllOrNothing {
@@ -260,11 +270,12 @@ impl ScorerBuilder for SumOfScorersBuilder {
         let scorers: Vec<_> = self
             .scorers
             .iter()
-            .map(|scorer| scorer.attach(cmd, actor))
+            .map(|scorer| scorer.spawn_scorer(cmd, actor))
             .collect();
         cmd.entity(scorer)
             .insert(Transform::default())
             .insert(GlobalTransform::default())
+            .push_children(&scorers[..])
             .insert(SumOfScorers {
                 threshold: self.threshold,
                 scorers: scorers.into_iter().map(ScorerEnt).collect(),
@@ -351,11 +362,12 @@ impl ScorerBuilder for WinningScorerBuilder {
         let scorers: Vec<_> = self
             .scorers
             .iter()
-            .map(|scorer| scorer.attach(cmd, actor))
+            .map(|scorer| scorer.spawn_scorer(cmd, actor))
             .collect();
         cmd.entity(scorer)
             .insert(Transform::default())
             .insert(GlobalTransform::default())
+            .push_children(&scorers[..])
             .insert(WinningScorer {
                 threshold: self.threshold,
                 scorers: scorers.into_iter().map(ScorerEnt).collect(),
@@ -373,7 +385,7 @@ unlike other composite scorers, `EvaluatingScorer` only takes one scorer upon bu
 Thinker::build()
     .when(
         EvaluatingScorer::build(MyScorer, MyEvaluator),
-        MyAction::build());
+        MyAction);
 ```
  */
 #[derive(Clone, Component, Debug)]
@@ -422,10 +434,12 @@ pub struct EvaluatingScorerBuilder {
 
 impl ScorerBuilder for EvaluatingScorerBuilder {
     fn build(&self, cmd: &mut Commands, scorer: Entity, actor: Entity) {
-        let inner_scorer = self.scorer.attach(cmd, actor);
+        let inner_scorer = self.scorer.spawn_scorer(cmd, actor);
+        let scorers = vec![inner_scorer];
         cmd.entity(scorer)
             .insert(Transform::default())
             .insert(GlobalTransform::default())
+            .push_children(&scorers[..])
             .insert(EvaluatingScorer {
                 evaluator: self.evaluator.clone(),
                 scorer: ScorerEnt(inner_scorer),
